netapp_ontap.models.fpolicy_engine_resiliency API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_engine_resiliency`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyEngineResiliencySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyEngineResiliency object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `directory_path: str GET POST PATCH`

    Specifies the directory path under the SVM namespace, where notifications are stored in the files whenever a network outage happens.

    Example: /dir1

  `enabled: bool GET POST PATCH`

    Specifies whether the resiliency feature is enabled or not. Default is false.

  `retention_duration: str GET POST PATCH`

    Specifies the ISO-8601 duration, for which the notifications are written to files inside the storage controller during a network outage. The value for this field must be between 0 and 600 seconds. Default is 180 seconds.

    Example: PT3M